# Printy

A python application that allows us to colorize the print statement with 
flags, for instance >>> printy("some text", "yBH") will apply a Bold 
Highlighted Yellow color to the text.

### DEMO

![Color Print Demo](github/color_print.gif)